Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2824)

Unified Diff: build/mac/change_mach_o_flags_from_xcode.sh

Issue 7714018: Give plug-in processes an executable heap and disable PIE/ASLR for Native (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/mac/change_mach_o_flags.py ('k') | build/mac/make_heap_non_executable.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/mac/change_mach_o_flags_from_xcode.sh
===================================================================
--- build/mac/change_mach_o_flags_from_xcode.sh (revision 97870)
+++ build/mac/change_mach_o_flags_from_xcode.sh (working copy)
@@ -4,12 +4,11 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
# This is a small wrapper script around make_heap_non_executable.py allowing
# it to be invoked easily from Xcode. make_heap_non_executable.py expects its
# argument on the command line, and Xcode puts all of its parameters in the
# environment.
set -e
-exec "$(dirname "${0}")/make_heap_non_executable.py" \
+exec "$(dirname "${0}")/change_mach_o_flags.py" \
"${BUILT_PRODUCTS_DIR}/${EXECUTABLE_PATH}"
« no previous file with comments | « build/mac/change_mach_o_flags.py ('k') | build/mac/make_heap_non_executable.py » ('j') | no next file with comments »
@@ -4,12 +4,11 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
-# This is a small wrapper script around make_heap_non_executable.py allowing
-# it to be invoked easily from Xcode. make_heap_non_executable.py expects its
-# argument on the command line, and Xcode puts all of its parameters in the
-# environment.
+# This is a small wrapper script around change_mach_o_flags.py allowing it to
+# be invoked easily from Xcode. change_mach_o_flags.py expects its arguments
+# on the command line, but Xcode puts its parameters in the environment.
set -e

Powered by Google App Engine
This is Rietveld 408576698